"""comparison_la_filter_button"""

from dash import html


def add_filter_button(style: dict, id_string: str):
    """
    Return a 'Compare to additional authority' button which is aligned to the right

    Args:
    style (dict): The CSS styling to add to the button.
    id_string (str): ID for the button.
    """
    return html.Div(
        [
            html.Button(
                "Compare to additional authority",
                id=id_string,
                n_clicks=0,
                className="govuk-button govuk-button--secondary comparison-button-background",
            ),
        ],
        className="govuk-button-group",
        style=style,
    )



"""key_value_pair"""

import numpy as np
from dash import html


def key_value_pair(key, value):
    """
    Create an HTML element that displays a value (such as a metric) labelled by a key (such as the
    name of the metric).
    """
    if isinstance(value, float):
        value_can_be_displayed = value is not None and not np.isnan(value)
    else:
        value_can_be_displayed = value is not None

    return [
        html.Dt(
            key,
            className="govuk-body-s govuk-!-margin-bottom-0",
        ),
        html.Dd(
            value if value_can_be_displayed else "-",
            className="govuk-heading-m govuk-!-margin-0 govuk-!-padding-0",
        ),
    ]



# """Line chart function"""
# from typing import Optional
# import plotly.express as px
# from gov_uk_dashboards.axes import calc_axis_range
# from gov_uk_dashboards.colours import ONSAccessibleColours
# from .styles import LineStyle
# from .chart_data import ChartData


# def line_chart(
#     data: ChartData,
#     title: str,
#     markers: bool = False,
#     line_styles: Optional[dict[str, LineStyle]] = None,
#     **px_line_kwargs,
# ):
#     """
#     Create and return a plotly express line chart with standard formatting.

#     Dataframe should be sorted so x axis is in the correct order for plotting.

#     If no style information provided, lines will be plotted as solid lines
#     using the ONSAcessibleColours enum for their colours.

#     Args:
#         data (ChartData): Data for the chart.
#         title (str): Title to be shown above the chart.
#         markers (bool, optional): Whether markers should be plotted for each point.
#             Defaults to False.
#         line_styles (dict[str, LineStyle], optional): A dictionary with keys that match
#             the categories in the category column (if supplied), and values that are
#             LineStyle data objects to set out the style of the corresponding line.
#             Defaults to None.
#         **px_line_kwargs: Any other keyword arguments to pass to the plotly express
#             line graph function.

#     Returns:
#         plotly.Figure: The generated line chart figure object.
#     """
#     color_discrete_map = None
#     line_dash_map = None
#     labels = None
#     if line_styles:
#         color_discrete_map = {
#             category: line_style.color for category, line_style in line_styles.items()
#         }
#         line_dash_map = {
#             category: line_style.dash_pattern
#             for category, line_style in line_styles.items()
#         }
#         # If line dashes are set, plotly express automatically appends the name of the dash style
#         # to the label in the legend/hover data.
#         # As this is normally not desired, labels are set manually to override this.
#         labels = {category: category for category in line_styles}

#     linechart = px.line(
#         data.dataframe,
#         x=data.x_column,
#         y=data.y_column,
#         range_y=calc_axis_range(data.dataframe, data.y_column),
#         color_discrete_map=color_discrete_map,
#         line_dash_map=line_dash_map,
#         line_dash=data.category_column,
#         color=data.category_column,
#         labels=labels,
#         markers=markers,
#         color_discrete_sequence=[colour.value for colour in ONSAccessibleColours]
#         if not line_styles
#         else None,
#         **px_line_kwargs,
#     )

#     linechart.update_layout(
#         title=title,
#         paper_bgcolor="rgba(0,0,0,0)",
#         plot_bgcolor="rgba(0,0,0,0)",
#         xaxis_type="category",
#     )

#     return linechart



"""HTML components for displaying messages to the user in a banner format"""

from dash import html


def message_banner(category, message, style=None):
    """
    Return a coronavirus dashboard-style changelog banner to be used to communicate to the user
    when the dashboard was last updated.

    See https://coronavirus.data.gov.uk
    """
    return html.Div(
        html.P(
            [
                html.Strong(
                    category,
                    className="govuk-tag",
                    style={
                        "background": "black",
                        "color": "white",
                        "margin": "0 1rem 0 0",
                        "lineHeight": "initial",
                    },
                ),
                message,
            ],
            className="govuk-body-s govuk-!-margin-bottom-0",
        ),
        className="change-log-banner govuk-!-margin-bottom-2",
        style=style,
    )



"""Module for logging configuration"""

import os

import logging


def configure_logging():
    """Configure logging to a given level."""
    logging_level = os.environ.get("LOGGING_LEVEL")
    if not logging_level:
        logging_level = logging.INFO

    logger = logging.getLogger("root")
    logger.setLevel(logging_level)
    logging.basicConfig()



"""Generate the wrapping information/header for a chart or table."""

from dash import html
from dash.development.base_component import Component

from gov_uk_dashboards.components.dash.download_button import (
    create_download_button_with_icon,
)
from gov_uk_dashboards.components.dash.heading import HeadingSizes
from gov_uk_dashboards.components.dash.paragraph import paragraph


# pylint: disable=too-many-arguments
# pylint: disable=too-many-positional-arguments
def display_chart_or_table_with_header(
    chart_or_table: Component,
    heading: str = None,
    sub_heading: str = None,
    download_button_id: str = None,
    download_data_button_id: str = None,
    download_map_button_id: str = None,
    footnote: str = None,
    instance=1,
    text_below_subheading: str = None,
) -> html.Div:
    """Generate the wrapping information/header for a chart or table.

    Args:
        chart_or_table (Component): the chart or table to display.
        heading (str, optional): the heading for the chart,
        sub_heading (str, optional): the sub-heading for the chart,
        download_button_id (str, optional): id for download button if required. Defaults to None.
                                            if None then the button will not be included.
        download_data_button_id (str, optional): the id to be applied to the download data button.
        download_map_button_id (str, optional): the id to be applied to the download map button.
        footnote (str, optional): the footnote to be added to charts and downloads.
        instance (int or str): Optional additional paramter for id dict.
        text_below_subheading (str, optional): Optional text to go below subheading but above
            chart_or_table.

    Returns:
        html.Div: Div containing Header and chart/table.
    """
    return html.Div(
        [
            html.Div(
                [
                    html.Div(
                        [
                            html.H2(
                                heading,
                                className=HeadingSizes.MEDIUM,
                                style={"color": "black", "margin": "0px 0px 5px"},
                            ),
                            html.H3(
                                sub_heading,
                                className=HeadingSizes.SMALL,
                                style={"color": "black", "margin": "0px 0px 5px"},
                            ),
                        ],
                    ),
                ]
            ),
            paragraph(text_below_subheading),
            chart_or_table,
            html.Div([paragraph(footnote)], style={"paddingTop": "20px"}),
            html.Div(
                (
                    [
                        html.Div(
                            [
                                (
                                    create_download_button_with_icon(
                                        "Download chart", download_button_id, instance
                                    )
                                    if download_button_id
                                    else []
                                ),
                                (
                                    create_download_button_with_icon(
                                        "Download map", download_map_button_id, instance
                                    )
                                    if download_map_button_id
                                    else []
                                ),
                                (
                                    create_download_button_with_icon(
                                        "Download data",
                                        download_data_button_id,
                                        instance,
                                    )
                                    if download_data_button_id
                                    else []
                                ),
                            ],
                            className="govuk-button-group",
                            style={"paddingTop": "20px"},
                        ),
                    ]
                ),
            ),
        ],
        className="container-class box_container_layout bg_white",
    )
